@@ -32,8 +32,8 @@ class AirTouchGroup:
         self.GroupNumber = 0
         self.IsOn = True
         self.OpenPercent = 0
-        self.CurrentRoomTemp = 0
-        self.TargetRoomTemp = 0
+        self.Temperature = 0
+        self.TargetSetpoint = 0
         self.BelongsToAc = -1
 
 class AirTouchAc:
@@ -45,10 +45,12 @@ class AirTouchAc:
 class AirTouch:
     IpAddress = "";
     def __init__(self, ipAddress):
+        self.IpAddress = ipAddress;
+        self.UpdateInfo();
+
+    def UpdateInfo(self):
         self.acs = dict();
         self.groups = dict();
-        self.IpAddress = ipAddress;
-        
         #get the group infos
         message = packetmap.MessageFactory.CreateEmptyMessageOfType("GroupStatus");
         self.SendMessageToAirtouch(message)
@@ -180,12 +182,15 @@ class AirTouch:
     def GetAcs(self):
         acs = [AirTouchAc];
         for acNumber in self.acs.keys(): 
-            ac = self.groups[acNumber]
+            ac = self.acs[acNumber]
             acs.append(ac);
         return acs;
+    
+    def GetGroupByGroupNumber(self, groupNumber):
+        return self.groups[groupNumber];
 
     def GetGroups(self):
-        groups = [AirTouchGroup];
+        groups = [];
         for groupNumber in self.groups.keys(): 
             groupInfo = self.groups[groupNumber]
             groups.append(groupInfo);
